@@ -4,6 +4,8 @@ import boto3
 import os
 from . import logger
 import logging
+import pkgutil
+from yaml import load, FullLoader
 logging.getLogger('s3transfer').setLevel(logging.CRITICAL)
 
 # Get log file
@@ -11,9 +13,10 @@ my_logger = logger.logger('ocr')
 
 
 class MLModel(metaclass=ABCMeta):
-    def __init__(self, model_name, config, model_id=None):
+    def __init__(self, model_name, model_id=None, config_version='current_model', do_not_update=False):
         self.model_name = model_name
-        self.config = config
+        self.config = self._get_config(config_version)
+        self.do_not_update = do_not_update
         self.model_id = self._get_model_id(model_id)
         self.load_model()
         my_logger.info('Model {} Loaded'.format(self.model_name))
@@ -28,6 +31,11 @@ class MLModel(metaclass=ABCMeta):
             aws_secret_access_key=os.environ['S3_SECRET']
         )
 
+    @staticmethod
+    def _get_config(config_version):
+        config = load(pkgutil.get_data(__name__, "config/{}.yaml".format(config_version)), Loader=FullLoader)
+        return config['model_name']
+
     def _upload_file(self, s3_client, file_name, bucket, object_name):
         """Upload a file to an S3 bucket
 
@@ -82,10 +90,11 @@ class MLModel(metaclass=ABCMeta):
             pass
 
     def schedule_model_check(self):
-        scheduler = BackgroundScheduler()
-        scheduler.add_job(self._load_if_model_updated, 'interval', minutes=5)
-        scheduler.add_job(self.train, 'interval', minutes=10)
-        scheduler.start()
+        if not self.do_not_update:
+            scheduler = BackgroundScheduler()
+            scheduler.add_job(self._load_if_model_updated, 'interval', minutes=5)
+            scheduler.add_job(self.train, 'interval', minutes=10)
+            scheduler.start()
 
     @abstractmethod
     def train(self):
